@@ -1,35 +1,37 @@
 import pytest
-import asynctest
+import sys
 
 import bleak
 
+if sys.version_info[:2] < (3, 8):
+    from asynctest import patch, MagicMock
+else:
+    from unittest.mock import patch, MagicMock
+
 
 @pytest.fixture
 def client_class():
-    with asynctest.patch('bleak.BleakClient', autospec=True) as client_class:
+    with patch('bleak.BleakClient', autospec=True) as client_class:
         yield client_class
 
 
 @pytest.fixture
 def client(client_class):
-    client = asynctest.MagicMock(spec=bleak.BleakClient)
+    client = MagicMock(spec=bleak.BleakClient)
     client_class.return_value = client
 
     connected = False
 
     async def is_connected():
         nonlocal connected
-        print("CALLING IS_CONNECTED")
         return connected
 
     async def connect():
         nonlocal connected
-        print("CALLING CONNECT")
         connected = True
 
     async def disconnect():
         nonlocal connected
-        print("CALLING DISCONNECT")
         connected = False
 
     client.is_connected.side_effect = is_connected
@@ -41,5 +43,5 @@ def client(client_class):
 
 @pytest.fixture
 def scanner():
-    with asynctest.patch('bleak.BleakScanner', autospec=True) as scanner:
+    with patch('bleak.BleakScanner', autospec=True) as scanner:
         yield scanner
